﻿# Console Information
if ($DebugMode -EQ $true) {
    Write-Host "Loading Configure.ps1"
    Write-Host "• Press [Enter] to continue."
    $Host.UI.RawUI.ReadKey('NoEcho,IncludeKeyDown') | Out-Null
    Write-Host ""
}

# Configuration File - File Reader
$Global:FilePath = ".\Configure.ini"
$Global:FileData = @{}
Switch -Regex -File $FilePath {
    “^\[(.+)\]” {
        $Section = $Matches[1]
        $FileData[$Section] = @{}
        $CommentCount = 0
    }
    “^(;.*)$” {
        $Value = $Matches[1]
        $CommentCount = $CommentCount + 1
        $Name = “Comment” + $CommentCount
        $FileData[$Section][$Name] = $Value
    }
    “(.+?)\s*=(.*)” {
        $Name,$Value = $Matches[1..2]
        $FileData[$Section][$Name] = $ExecutionContext.InvokeCommand.ExpandString($Value.Trim('"'))
    }
}

# Configuration File - Set Variables [Hidden]
if ($FileData.Miscellaneous.Hidden -NE "") {
    $Global:HiddenMode = $FileData.Miscellaneous.Hidden
} else {
    $Global:HiddenMode = "Error"
}

# Configuration File - Set Variables [Shortcut]
if ($FileData.Miscellaneous.Shortcut -NE "") {
    $Global:ShortcutMode = $FileData.Miscellaneous.Shortcut
} else {
    $Global:ShortcutMode = "Error"
}

# Configuration File - Set Variables [Registry]
if ($FileData.Miscellaneous.Registry -NE "") {
    $Global:RegistryMode = $FileData.Miscellaneous.Registry
} else {
    $Global:RegistryMode = "Error"
}

# Configuration File - Set Variables [Destruct]
if ($FileData.Miscellaneous.Destruct -NE "") {
    $Global:DestructMode = $FileData.Miscellaneous.Destruct
} else {
    $Global:DestructMode = "Error"
}

# Configuration File - Set Variables [Shutdown]
if ($FileData.Miscellaneous.Shutdown -NE "") {
    $Global:ShutdownMode = $FileData.Miscellaneous.Shutdown
} else {
    $Global:ShutdownMode = "Error"
}

# Configuration File - Set Variables [Terminate]
if ($FileData.Miscellaneous.Terminate -NE "") {
    $Global:TerminateMode = $FileData.Miscellaneous.Terminate
} else {
    $Global:TerminateMode = "Error"
}

# Configuration File - Set Variables [Processes]
if ($FileData.Miscellaneous.Processes -NE "") {
    $Global:ProcessesList = $FileData.Miscellaneous.Processes
} else {
    $Global:ProcessesList = "Error"
}

# Configuration File - Set Variables [ModuleFile]
if ($FileData.Miscellaneous.ModuleFile -NE "") {
    $Global:ModuleFile = $FileData.Miscellaneous.ModuleFile
} else {
    $Global:ModuleFile = "Error"
}

# Configuration File - Set Variables [Versioning]
if ($FileData.Miscellaneous.Versioning -NE "") {
    $Global:Versioning = $FileData.Miscellaneous.Versioning
} else {
    $Global:Versioning = "Error"
}

# Console Information
if ($VerboseMode -EQ $true) {
    Write-Host "Configuration File"
    Write-Host "• Hidden: $HiddenMode"
    Write-Host "• Shortcut: $ShortcutMode"
    Write-Host "• Registry: $RegistryMode"
    Write-Host "• Destruct: $DestructMode"
    Write-Host "• Shutdown: $ShutdownMode"
    Write-Host "• Terminate: $TerminateMode"
    Write-Host "• Processes: $ProcessesList"
    Write-Host "• ModuleFile: $ModuleFile"
    Write-Host "• Versioning: $Versioning"
    Write-Host ""
}

# Console Information
if ($DebugMode -EQ $true) {
    Write-Host "Finished Configure.ps1"
    Write-Host "• Press [Enter] to continue."
    $Host.UI.RawUI.ReadKey('NoEcho,IncludeKeyDown') | Out-Null
    Write-Host ""
}