﻿# Console Information
if ($DebugMode -EQ $true) {
    Write-Host "Loading Registry.ps1"
    Write-Host "• Press [Enter] to continue."
    $Host.UI.RawUI.ReadKey('NoEcho,IncludeKeyDown') | Out-Null
    Write-Host ""
}

# Execute Setup Instructions
if ($ExecutableMode -EQ "Setup") {

    if ($RegistryMode -Match "Enable") {

        # Remove Install Entry
        function Remove-Registry {
            [CmdletBinding()] param (
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$KeyPath,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$KeyName
            ) process {
                Remove-Item Registry::"$KeyPath\$KeyName" -Force -Recurse
            }
        }

        # Create Install Entry
        function Create-Registry {
            [CmdletBinding()] param (
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$DisplayName,
                [Parameter(ValueFromPipelineByPropertyName)][String]$DisplayIcon,
                [Parameter(ValueFromPipelineByPropertyName)][String]$DisplayVersion,
                [Parameter(ValueFromPipelineByPropertyName)][String]$Publisher,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$InstallLocation,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$UninstallString,
                [Parameter(ValueFromPipelineByPropertyName)][String]$EstimatedSize,
                [Parameter(ValueFromPipelineByPropertyName)][String]$NoModify,
                [Parameter(ValueFromPipelineByPropertyName)][String]$NoRepair,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$KeyPath,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$KeyName
            ) process {
                New-Item Registry::"$KeyPath" -Name "$KeyName" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "DisplayName" -Value "$DisplayName" -PropertyType "String" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "DisplayIcon" -Value "$DisplayIcon" -PropertyType "String" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "DisplayVersion" -Value "$DisplayVersion" -PropertyType "String" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "Publisher" -Value "$Publisher" -PropertyType "String" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "InstallLocation" -Value "$InstallLocation" -PropertyType "String" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "UninstallString" -Value "$UninstallString" -PropertyType "String" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "EstimatedSize" -Value "$EstimatedSize" -PropertyType "DWord" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "NoModify" -Value "$NoModify" -PropertyType "DWord" -Force | Out-Null
                New-ItemProperty Registry::"$KeyPath\$KeyName" -Name "NoRepair" -Value "$NoRepair" -PropertyType "DWord" -Force | Out-Null
            }
        }

        # Run Instructions
        $RegistrySorcerer | Remove-Registry
        $RegistrySorcerer | Create-Registry

    }

}

# Execute Removal Instructions
if ($ExecutableMode -EQ "Remove") {

    if ($RegistryMode -Match "Enable") {

        # Remove Install Entry
        function Remove-Registry {
            [CmdletBinding()] param (
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$KeyPath,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$KeyName
            ) process {
                Remove-Item Registry::"$KeyPath\$KeyName" -Force -Recurse
            }
        }

        # Run Instructions
        $RegistrySorcerer | Remove-Registry

    }

}

# Console Information
if ($DebugMode -EQ $true) {
    Write-Host "Finished Registry.ps1"
    Write-Host "• Press [Enter] to continue."
    $Host.UI.RawUI.ReadKey('NoEcho,IncludeKeyDown') | Out-Null
    Write-Host ""
}