﻿# Console Information
if ($DebugMode -EQ $true) {
    Write-Host "Loading Shortcut.ps1"
    Write-Host "• Press [Enter] to continue."
    $Host.UI.RawUI.ReadKey('NoEcho,IncludeKeyDown') | Out-Null
    Write-Host ""
}

# Execute Setup Instructions
if ($ExecutableMode -EQ "Setup") {

    if ($ShortcutMode -Match "Enable") {

        # Remove Shortcut
        function Remove-Shortcut {
            [CmdletBinding()] param (
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$Path,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$Name
            ) process {
                Remove-Item "$Path\$Name.lnk" -Force
            }
        }

        # Create Shortcut
        function Create-Shortcut {
            [CmdletBinding()] param (
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$Path,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$Name,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$TargetPath,
                [Parameter(ValueFromPipelineByPropertyName)][String]$Arguments,
                [Parameter(ValueFromPipelineByPropertyName)][String]$WorkingDirectory,
                [Parameter(ValueFromPipelineByPropertyName)][String]$IconLocation,
                [Parameter(ValueFromPipelineByPropertyName)][String]$Description,
                [Parameter(ValueFromPipelineByPropertyName)][Int]$WindowStyle,
                [Parameter(ValueFromPipelineByPropertyName)][String]$Hotkey
            ) begin {
                $Shell = New-Object -ComObject WScript.Shell
            } process {
                $Shortcut = $Shell.CreateShortcut("$Path\$Name.lnk")
                ForEach ($Parameter in $PSBoundParameters.Keys) {
                    if ($Shortcut.PSObject.Properties.Item($Parameter)) {
                        $Shortcut.$Parameter = $PSBoundParameters[$Parameter]
                    }
                }
                $Shortcut.Save()
            }
        }
        
        # Run Instructions
        $ShortcutSorcerer | Remove-Shortcut
        $ShortcutSorcerer | Create-Shortcut

    }

}

# Execute Removal Instructions
if ($ExecutableMode -EQ "Remove") {

    if ($ShortcutMode -Match "Enable") {

        # Remove Shortcut
        function Remove-Shortcut {
            [CmdletBinding()] param (
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$Path,
                [Parameter(Mandatory, ValueFromPipelineByPropertyName)][String]$Name
            ) process {
                Remove-Item "$Path\$Name.lnk" -Force
            }
        }
        
        # Run Instructions
        $ShortcutSorcerer | Remove-Shortcut

    }

}

# Console Information
if ($DebugMode -EQ $true) {
    Write-Host "Finished Shortcut.ps1"
    Write-Host "• Press [Enter] to continue."
    $Host.UI.RawUI.ReadKey('NoEcho,IncludeKeyDown') | Out-Null
    Write-Host ""
}